# Modelling

There are several ways in which network service products can be modelled and
split up into logical parts (product blocks). This may for example depend on the
requirements from the stakeholders, the environment such products are used in,
and/or personal taste. It is important to highlight that the modelling process
aims to identify the main attributes necessary to describe a product and the
relations between product blocks – it is not prescriptive in terms of design and
implementation of a specific product. This approach helps to decouple the two
topics and keep them in separate functional domains.

Looking at different sets of network service product models we do see that they
share a set of core attributes, regardless of which product or product block
they belong to. This is not surprising, because the key attributes needed to
actually provision a network service on the network are the same for all of
these. This sections describes a set of network service product models and their
attributes that can either be extended to meet the specific needs of the
environment they will be used in, or can serve as a basis for a new
constellation of product models. There is no intention to supply a complete set
of products that covers all possible NREN network services, but it should be
enough to help inspire thinking about (network) product modelling in your
organisation.
